﻿''' <summary>
''' Provides a dialog window that allows the user to select a container from a specified Active Directory domain
''' </summary>
Public Class SelectAdContainerDialog : Implements IDisposable


#Region "Private Objects"

    Private _AdForm As New AdTreeViewForm

#End Region


#Region "Public Properties"

    Private _SelectedContainerPath As String = String.Empty
    ''' <summary>
    ''' Contains the full distinguished name for the container the user selected once the form has been shown
    ''' </summary>
    Public ReadOnly Property SelectedContainerPath() As String
        Get
            Return _SelectedContainerPath
        End Get
    End Property

    Private _Username As String = String.Empty
    ''' <summary>
    ''' The username to use for the connection to the domain
    ''' </summary>
    Public WriteOnly Property Username() As String
        Set(ByVal value As String)
            _Username = value
        End Set
    End Property

    Private _Password As String = String.Empty
    ''' <summary>
    ''' The password to use for the connection to the domain
    ''' </summary>
    Public WriteOnly Property Password() As String
        Set(ByVal value As String)
            _Password = value
        End Set
    End Property

    Private _DomainName As String = String.Empty
    ''' <summary>
    ''' The full DNS name of the domain to show the container tree for. If this property is not set, the current user's domain will be used
    ''' </summary>
    Public Property DomainName() As String
        Get
            Return _DomainName
        End Get
        Set(ByVal value As String)
            _DomainName = value
        End Set
    End Property

    Private _Title As String = String.Empty
    ''' <summary>
    ''' A title or description to be shown at the top of the form
    ''' </summary>
    Public Property Title() As String
        Get
            Return _Title
        End Get
        Set(ByVal value As String)
            _Title = value
        End Set
    End Property

#End Region


#Region "Public Methods"

    ''' <summary>
    ''' Shows the Active Directory container selection dialog as a modal window and returns once the dialog has been closed. 
    ''' The distinguished name of the container the user selected will then be held in the SelectedContainerPath property
    ''' </summary>
    Public Function ShowDialog() As Windows.Forms.DialogResult
        With _AdForm
            .Username = Me._Username
            .Password = Me._Password
            .TitleLbl.Text = Me._Title
            .DomainName = Me._DomainName
        End With
        Dim ShowDialogResult = _AdForm.ShowDialog
        If ShowDialogResult = Windows.Forms.DialogResult.OK Then
            Me._SelectedContainerPath = _AdForm.SelectedContainerPath
        Else
            Me._SelectedContainerPath = String.Empty
        End If
        Return ShowDialogResult
    End Function

#End Region


#Region "IDisposable Support"

    Private disposedValue As Boolean

    Protected Overridable Sub Dispose(ByVal disposing As Boolean)
        If Not Me.disposedValue Then
            If disposing Then
                If Not _AdForm Is Nothing AndAlso Not _AdForm.IsDisposed Then
                    _AdForm.Dispose()
                End If
            End If
        End If
        Me.disposedValue = True
    End Sub

    Public Sub Dispose() Implements IDisposable.Dispose
        ' Do not change this code.  Put cleanup code in Dispose(ByVal disposing As Boolean) above.
        Dispose(True)
        GC.SuppressFinalize(Me)
    End Sub

#End Region

End Class
